@@ -3,7 +3,6 @@ import platform
 import re
 import ssl
 
-import pkg_resources
 import requests
 
 from .error import RequestError, RequestSetupError
@@ -18,6 +17,8 @@ from .resources.payment_chargebacks import PaymentChargebacks
 from .resources.payment_refunds import PaymentRefunds
 from .resources.payments import Payments
 from .resources.refunds import Refunds
+from .resources.subscription_payments import SubscriptionPayments
+from .version import VERSION
 
 try:
     from urllib.parse import urlencode
@@ -27,7 +28,7 @@ except ImportError:
 
 
 class Client(object):
-    CLIENT_VERSION = '2.0.6'
+    CLIENT_VERSION = VERSION
     API_ENDPOINT = 'https://api.mollie.com'
     API_VERSION = 'v2'
     UNAME = ' '.join(platform.uname())
@@ -65,6 +66,7 @@ class Client(object):
         self.customer_subscriptions = CustomerSubscriptions(self)
         self.customer_payments = CustomerPayments(self)
         self.orders = Orders(self)
+        self.subscription_payments = SubscriptionPayments(self)
 
     def set_api_endpoint(self, api_endpoint):
         self.api_endpoint = self.validate_api_endpoint(api_endpoint)
@@ -75,12 +77,6 @@ class Client(object):
     def set_timeout(self, timeout):
         self.timeout = timeout
 
-    def get_cacert(self):
-        cacert = pkg_resources.resource_filename('mollie.api', 'cacert.pem')
-        if not cacert or len(cacert) < 1:
-            raise RequestSetupError('Unable to load cacert.pem')
-        return cacert
-
     def perform_http_call(self, http_method, path, data=None, params=None):
         if not self.api_key:
             raise RequestSetupError('You have not set an API key. Please use set_api_key() to set the API key.')
@@ -100,11 +96,10 @@ class Client(object):
             url += '?' + querystring
             params = None
 
-        cacert = self.get_cacert()
         try:
             response = requests.request(
                 http_method, url,
-                verify=cacert,
+                verify=True,
                 headers={
                     'Accept': 'application/json',
                     'Authorization': 'Bearer {api_key}'.format(api_key=self.api_key),
