@@ -106,14 +106,13 @@ def test_get_single_payment(client, response):
     assert payment.sequence_type == Payment.SEQUENCETYPE_RECURRING
     assert payment.mandate_id == MANDATE_ID
     assert payment.subscription_id == SUBSCRIPTION_ID
-    assert payment.order_id is None
+    assert payment.order_id == ORDER_ID
     assert payment.application_fee is None
     assert payment.details is None
     # properties from _links
     assert payment.checkout_url == 'https://www.mollie.com/payscreen/select-method/7UhSN1zuXS'
     assert payment.refunds is not None
     assert payment.chargebacks is not None
-    assert payment.settlement is None
     assert payment.mandate is not None
     assert payment.subscription is not None
     assert payment.customer is not None
